[ObjC] rename the file to drop the "objectivec_" prefix.
Since "names.(h|cc)" now exists, drop the prefixing on all the files.
diff --git a/objectivec/DevTools/check_version_stamps.sh b/objectivec/DevTools/check_version_stamps.sh
index a3524cb..5972e35 100755
--- a/objectivec/DevTools/check_version_stamps.sh
+++ b/objectivec/DevTools/check_version_stamps.sh
@@ -16,7 +16,7 @@
exit 1
}
-readonly GeneratorSrc="${ProtoRootDir}/src/google/protobuf/compiler/objectivec/objectivec_file.cc"
+readonly GeneratorSrc="${ProtoRootDir}/src/google/protobuf/compiler/objectivec/file.cc"
readonly RuntimeSrc="${ProtoRootDir}/objectivec/GPBBootstrap.h"
check_constant() {
diff --git a/objectivec/GPBDescriptor.m b/objectivec/GPBDescriptor.m
index 72368ce..316ce76 100644
--- a/objectivec/GPBDescriptor.m
+++ b/objectivec/GPBDescriptor.m
@@ -681,7 +681,7 @@
}
// The logic here has to match SetCommonFieldVariables() from
- // objectivec_field.cc in the proto compiler.
+ // objectivec/field.cc in the proto compiler.
NSString *name = self.name;
NSUInteger len = [name length];
@@ -918,7 +918,7 @@
if (extraTextFormatInfo_) {
result = GPBDecodeTextFormatName(extraTextFormatInfo_, (int32_t)index, shortName);
}
- // Logic here needs to match what objectivec_enum.cc does in the proto
+ // Logic here needs to match what objectivec/enum.cc does in the proto
// compiler.
if (result == nil) {
NSUInteger len = [shortName length];
diff --git a/objectivec/Tests/GPBMessageTests.m b/objectivec/Tests/GPBMessageTests.m
index 83b8d11..7d4cf79 100644
--- a/objectivec/Tests/GPBMessageTests.m
+++ b/objectivec/Tests/GPBMessageTests.m
@@ -1843,8 +1843,8 @@
}
- (void)testPropertyNaming {
- // objectivec_helpers.cc has some special handing to get proper all caps
- // for a few cases to meet objc developer expectations.
+ // names.cc has some special handing to get proper all caps for a few cases to
+ // meet objc developer expectations.
//
// This "test" confirms that the expected names are generated, otherwise the
// test itself will fail to compile.
@@ -1861,7 +1861,7 @@
}
- (void)testEnumNaming {
- // objectivec_helpers.cc has some interesting cases to deal with in
+ // names.cc has some interesting cases to deal with in
// EnumValueName/EnumValueShortName. Confirm that things generated as
// expected.
@@ -1966,9 +1966,8 @@
}
- (void)testReservedWordNaming {
- // objectivec_helpers.cc has some special handing to make sure that
- // some "reserved" objc names get renamed in a way so they
- // don't conflict.
+ // names.cc has some special handing to make sure that some "reserved" objc
+ // names get renamed in a way so they don't conflict.
//
// This "test" confirms that the expected names are generated,
// otherwise the test itself will fail to compile.
diff --git a/src/file_lists.cmake b/src/file_lists.cmake
index e874574..c701b66 100644
--- a/src/file_lists.cmake
+++ b/src/file_lists.cmake
@@ -350,18 +350,18 @@
${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/java/shared_code_generator.cc
${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/java/string_field.cc
${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/java/string_field_lite.cc
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/enum.cc
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/enum_field.cc
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/extension.cc
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/field.cc
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/file.cc
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/generator.cc
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/map_field.cc
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/message.cc
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/message_field.cc
${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/names.cc
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_enum.cc
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_enum_field.cc
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_extension.cc
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_field.cc
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_file.cc
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_generator.cc
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_map_field.cc
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_message.cc
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_message_field.cc
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_oneof.cc
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_primitive_field.cc
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/oneof.cc
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/primitive_field.cc
${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/php/names.cc
${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/php/php_generator.cc
${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/plugin.cc
@@ -446,21 +446,21 @@
${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/java/shared_code_generator.h
${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/java/string_field.h
${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/java/string_field_lite.h
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/enum.h
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/enum_field.h
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/extension.h
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/field.h
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/file.h
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/generator.h
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/helpers.h
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/map_field.h
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/message.h
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/message_field.h
${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/names.h
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_enum.h
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_enum_field.h
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_extension.h
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_field.h
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_file.h
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_generator.h
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_helpers.h
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_map_field.h
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_message.h
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_message_field.h
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_nsobject_methods.h
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_oneof.h
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_options.h
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_primitive_field.h
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/nsobject_methods.h
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/oneof.h
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/options.h
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/primitive_field.h
${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/php/names.h
${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/php/php_generator.h
${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/plugin.h
@@ -679,7 +679,7 @@
${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/java/doc_comment_unittest.cc
${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/java/message_serialization_unittest.cc
${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/java/plugin_unittest.cc
- ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/objectivec_helpers_unittest.cc
+ ${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/objectivec/helpers_unittest.cc
${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/parser_unittest.cc
${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/python/plugin_unittest.cc
${protobuf_SOURCE_DIR}/src/google/protobuf/compiler/ruby/ruby_generator_unittest.cc
diff --git a/src/google/protobuf/compiler/main.cc b/src/google/protobuf/compiler/main.cc
index ecaf76b..052943e 100644
--- a/src/google/protobuf/compiler/main.cc
+++ b/src/google/protobuf/compiler/main.cc
@@ -33,7 +33,7 @@
#include "google/protobuf/compiler/java/kotlin_generator.h"
#include "google/protobuf/compiler/command_line_interface.h"
#include "google/protobuf/compiler/csharp/csharp_generator.h"
-#include "google/protobuf/compiler/objectivec/objectivec_generator.h"
+#include "google/protobuf/compiler/objectivec/generator.h"
#include "google/protobuf/compiler/php/php_generator.h"
#include "google/protobuf/compiler/python/generator.h"
#include "google/protobuf/compiler/python/pyi_generator.h"
diff --git a/src/google/protobuf/compiler/objectivec/BUILD.bazel b/src/google/protobuf/compiler/objectivec/BUILD.bazel
index 248e2ab..465888c 100644
--- a/src/google/protobuf/compiler/objectivec/BUILD.bazel
+++ b/src/google/protobuf/compiler/objectivec/BUILD.bazel
@@ -21,7 +21,7 @@
name = "names_internal",
hdrs = [
"names.h",
- "objectivec_nsobject_methods.h",
+ "nsobject_methods.h",
],
srcs = [
"names.cc",
@@ -38,32 +38,32 @@
cc_library(
name = "objectivec",
srcs = [
- "objectivec_enum.cc",
- "objectivec_enum_field.cc",
- "objectivec_extension.cc",
- "objectivec_field.cc",
- "objectivec_file.cc",
- "objectivec_generator.cc",
- "objectivec_map_field.cc",
- "objectivec_message.cc",
- "objectivec_message_field.cc",
- "objectivec_oneof.cc",
- "objectivec_primitive_field.cc",
+ "enum.cc",
+ "enum_field.cc",
+ "extension.cc",
+ "field.cc",
+ "file.cc",
+ "generator.cc",
+ "map_field.cc",
+ "message.cc",
+ "message_field.cc",
+ "oneof.cc",
+ "primitive_field.cc",
],
hdrs = [
- "objectivec_enum.h",
- "objectivec_enum_field.h",
- "objectivec_extension.h",
- "objectivec_field.h",
- "objectivec_file.h",
- "objectivec_generator.h",
- "objectivec_helpers.h",
- "objectivec_map_field.h",
- "objectivec_message.h",
- "objectivec_message_field.h",
- "objectivec_oneof.h",
- "objectivec_options.h",
- "objectivec_primitive_field.h",
+ "enum.h",
+ "enum_field.h",
+ "extension.h",
+ "field.h",
+ "file.h",
+ "generator.h",
+ "helpers.h",
+ "map_field.h",
+ "message.h",
+ "message_field.h",
+ "oneof.h",
+ "options.h",
+ "primitive_field.h",
],
copts = COPTS,
include_prefix = "google/protobuf/compiler/objectivec",
@@ -81,7 +81,7 @@
cc_test(
name = "helpers_unittest",
- srcs = ["objectivec_helpers_unittest.cc"],
+ srcs = ["helpers_unittest.cc"],
deps = [
":objectivec",
"//src/google/protobuf/io",
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_enum.cc b/src/google/protobuf/compiler/objectivec/enum.cc
similarity index 98%
rename from src/google/protobuf/compiler/objectivec/objectivec_enum.cc
rename to src/google/protobuf/compiler/objectivec/enum.cc
index 13954ca..32a2549 100644
--- a/src/google/protobuf/compiler/objectivec/objectivec_enum.cc
+++ b/src/google/protobuf/compiler/objectivec/enum.cc
@@ -28,7 +28,7 @@
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#include "google/protobuf/compiler/objectivec/objectivec_enum.h"
+#include "google/protobuf/compiler/objectivec/enum.h"
#include <algorithm>
#include <map>
@@ -36,7 +36,7 @@
#include "absl/strings/escaping.h"
#include "absl/strings/str_cat.h"
-#include "google/protobuf/compiler/objectivec/objectivec_helpers.h"
+#include "google/protobuf/compiler/objectivec/helpers.h"
#include "google/protobuf/io/printer.h"
namespace google {
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_enum.h b/src/google/protobuf/compiler/objectivec/enum.h
similarity index 100%
rename from src/google/protobuf/compiler/objectivec/objectivec_enum.h
rename to src/google/protobuf/compiler/objectivec/enum.h
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_enum_field.cc b/src/google/protobuf/compiler/objectivec/enum_field.cc
similarity index 97%
rename from src/google/protobuf/compiler/objectivec/objectivec_enum_field.cc
rename to src/google/protobuf/compiler/objectivec/enum_field.cc
index 049ff47..58d4ed9 100644
--- a/src/google/protobuf/compiler/objectivec/objectivec_enum_field.cc
+++ b/src/google/protobuf/compiler/objectivec/enum_field.cc
@@ -31,8 +31,8 @@
#include <map>
#include <string>
-#include "google/protobuf/compiler/objectivec/objectivec_enum_field.h"
-#include "google/protobuf/compiler/objectivec/objectivec_helpers.h"
+#include "google/protobuf/compiler/objectivec/enum_field.h"
+#include "google/protobuf/compiler/objectivec/helpers.h"
#include "google/protobuf/io/printer.h"
namespace google {
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_enum_field.h b/src/google/protobuf/compiler/objectivec/enum_field.h
similarity index 97%
rename from src/google/protobuf/compiler/objectivec/objectivec_enum_field.h
rename to src/google/protobuf/compiler/objectivec/enum_field.h
index 7bd3c32..1cbd6cf 100644
--- a/src/google/protobuf/compiler/objectivec/objectivec_enum_field.h
+++ b/src/google/protobuf/compiler/objectivec/enum_field.h
@@ -33,7 +33,7 @@
#include <map>
#include <string>
-#include "google/protobuf/compiler/objectivec/objectivec_field.h"
+#include "google/protobuf/compiler/objectivec/field.h"
namespace google {
namespace protobuf {
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_extension.cc b/src/google/protobuf/compiler/objectivec/extension.cc
similarity index 97%
rename from src/google/protobuf/compiler/objectivec/objectivec_extension.cc
rename to src/google/protobuf/compiler/objectivec/extension.cc
index c97c9fe..fce45e5 100644
--- a/src/google/protobuf/compiler/objectivec/objectivec_extension.cc
+++ b/src/google/protobuf/compiler/objectivec/extension.cc
@@ -28,12 +28,12 @@
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#include "google/protobuf/compiler/objectivec/objectivec_extension.h"
+#include "google/protobuf/compiler/objectivec/extension.h"
#include <iostream>
#include "absl/strings/str_cat.h"
-#include "google/protobuf/compiler/objectivec/objectivec_helpers.h"
+#include "google/protobuf/compiler/objectivec/helpers.h"
#include "google/protobuf/descriptor.pb.h"
#include "google/protobuf/io/printer.h"
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_extension.h b/src/google/protobuf/compiler/objectivec/extension.h
similarity index 100%
rename from src/google/protobuf/compiler/objectivec/objectivec_extension.h
rename to src/google/protobuf/compiler/objectivec/extension.h
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_field.cc b/src/google/protobuf/compiler/objectivec/field.cc
similarity index 97%
rename from src/google/protobuf/compiler/objectivec/objectivec_field.cc
rename to src/google/protobuf/compiler/objectivec/field.cc
index b98955b..8c19294 100644
--- a/src/google/protobuf/compiler/objectivec/objectivec_field.cc
+++ b/src/google/protobuf/compiler/objectivec/field.cc
@@ -28,16 +28,16 @@
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#include "google/protobuf/compiler/objectivec/objectivec_field.h"
+#include "google/protobuf/compiler/objectivec/field.h"
#include <iostream>
#include "absl/strings/str_cat.h"
-#include "google/protobuf/compiler/objectivec/objectivec_enum_field.h"
-#include "google/protobuf/compiler/objectivec/objectivec_helpers.h"
-#include "google/protobuf/compiler/objectivec/objectivec_map_field.h"
-#include "google/protobuf/compiler/objectivec/objectivec_message_field.h"
-#include "google/protobuf/compiler/objectivec/objectivec_primitive_field.h"
+#include "google/protobuf/compiler/objectivec/enum_field.h"
+#include "google/protobuf/compiler/objectivec/helpers.h"
+#include "google/protobuf/compiler/objectivec/map_field.h"
+#include "google/protobuf/compiler/objectivec/message_field.h"
+#include "google/protobuf/compiler/objectivec/primitive_field.h"
#include "google/protobuf/io/printer.h"
namespace google {
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_field.h b/src/google/protobuf/compiler/objectivec/field.h
similarity index 100%
rename from src/google/protobuf/compiler/objectivec/objectivec_field.h
rename to src/google/protobuf/compiler/objectivec/field.h
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_file.cc b/src/google/protobuf/compiler/objectivec/file.cc
similarity index 98%
rename from src/google/protobuf/compiler/objectivec/objectivec_file.cc
rename to src/google/protobuf/compiler/objectivec/file.cc
index fc51baf..d09ed7e 100644
--- a/src/google/protobuf/compiler/objectivec/objectivec_file.cc
+++ b/src/google/protobuf/compiler/objectivec/file.cc
@@ -28,7 +28,7 @@
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#include "google/protobuf/compiler/objectivec/objectivec_file.h"
+#include "google/protobuf/compiler/objectivec/file.h"
#include <algorithm>
#include <iostream>
@@ -36,10 +36,10 @@
#include "google/protobuf/compiler/code_generator.h"
#include "absl/strings/str_cat.h"
-#include "google/protobuf/compiler/objectivec/objectivec_enum.h"
-#include "google/protobuf/compiler/objectivec/objectivec_extension.h"
-#include "google/protobuf/compiler/objectivec/objectivec_helpers.h"
-#include "google/protobuf/compiler/objectivec/objectivec_message.h"
+#include "google/protobuf/compiler/objectivec/enum.h"
+#include "google/protobuf/compiler/objectivec/extension.h"
+#include "google/protobuf/compiler/objectivec/helpers.h"
+#include "google/protobuf/compiler/objectivec/message.h"
#include "google/protobuf/io/printer.h"
// NOTE: src/google/protobuf/compiler/plugin.cc makes use of cerr for some
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_file.h b/src/google/protobuf/compiler/objectivec/file.h
similarity index 97%
rename from src/google/protobuf/compiler/objectivec/objectivec_file.h
rename to src/google/protobuf/compiler/objectivec/file.h
index 5063611..1af0f54 100644
--- a/src/google/protobuf/compiler/objectivec/objectivec_file.h
+++ b/src/google/protobuf/compiler/objectivec/file.h
@@ -35,7 +35,7 @@
#include <unordered_map>
#include <unordered_set>
#include <vector>
-#include "google/protobuf/compiler/objectivec/objectivec_options.h"
+#include "google/protobuf/compiler/objectivec/options.h"
#include "google/protobuf/descriptor.h"
#include "google/protobuf/io/printer.h"
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_generator.cc b/src/google/protobuf/compiler/objectivec/generator.cc
similarity index 98%
rename from src/google/protobuf/compiler/objectivec/objectivec_generator.cc
rename to src/google/protobuf/compiler/objectivec/generator.cc
index e5f2fb3..e0e0e29 100644
--- a/src/google/protobuf/compiler/objectivec/objectivec_generator.cc
+++ b/src/google/protobuf/compiler/objectivec/generator.cc
@@ -28,7 +28,7 @@
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#include "google/protobuf/compiler/objectivec/objectivec_generator.h"
+#include "google/protobuf/compiler/objectivec/generator.h"
#include <fstream>
#include <iostream>
@@ -38,8 +38,8 @@
#include "absl/strings/ascii.h"
#include "absl/strings/str_split.h"
#include "absl/strings/strip.h"
-#include "google/protobuf/compiler/objectivec/objectivec_file.h"
-#include "google/protobuf/compiler/objectivec/objectivec_helpers.h"
+#include "google/protobuf/compiler/objectivec/file.h"
+#include "google/protobuf/compiler/objectivec/helpers.h"
#include "google/protobuf/io/printer.h"
#include "google/protobuf/io/zero_copy_stream.h"
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_generator.h b/src/google/protobuf/compiler/objectivec/generator.h
similarity index 100%
rename from src/google/protobuf/compiler/objectivec/objectivec_generator.h
rename to src/google/protobuf/compiler/objectivec/generator.h
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_helpers.h b/src/google/protobuf/compiler/objectivec/helpers.h
similarity index 100%
rename from src/google/protobuf/compiler/objectivec/objectivec_helpers.h
rename to src/google/protobuf/compiler/objectivec/helpers.h
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_helpers_unittest.cc b/src/google/protobuf/compiler/objectivec/helpers_unittest.cc
similarity index 99%
rename from src/google/protobuf/compiler/objectivec/objectivec_helpers_unittest.cc
rename to src/google/protobuf/compiler/objectivec/helpers_unittest.cc
index e6d0a7c..d73efb3 100644
--- a/src/google/protobuf/compiler/objectivec/objectivec_helpers_unittest.cc
+++ b/src/google/protobuf/compiler/objectivec/helpers_unittest.cc
@@ -28,7 +28,7 @@
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#include "google/protobuf/compiler/objectivec/objectivec_helpers.h"
+#include "google/protobuf/compiler/objectivec/helpers.h"
#include "google/protobuf/io/zero_copy_stream_impl_lite.h"
#include <gtest/gtest.h>
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_map_field.cc b/src/google/protobuf/compiler/objectivec/map_field.cc
similarity index 98%
rename from src/google/protobuf/compiler/objectivec/objectivec_map_field.cc
rename to src/google/protobuf/compiler/objectivec/map_field.cc
index 087bd8f..bbc590c 100644
--- a/src/google/protobuf/compiler/objectivec/objectivec_map_field.cc
+++ b/src/google/protobuf/compiler/objectivec/map_field.cc
@@ -31,8 +31,8 @@
#include <map>
#include <string>
-#include "google/protobuf/compiler/objectivec/objectivec_map_field.h"
-#include "google/protobuf/compiler/objectivec/objectivec_helpers.h"
+#include "google/protobuf/compiler/objectivec/map_field.h"
+#include "google/protobuf/compiler/objectivec/helpers.h"
#include "google/protobuf/io/printer.h"
namespace google {
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_map_field.h b/src/google/protobuf/compiler/objectivec/map_field.h
similarity index 97%
rename from src/google/protobuf/compiler/objectivec/objectivec_map_field.h
rename to src/google/protobuf/compiler/objectivec/map_field.h
index 20c538e..bea9f6d 100644
--- a/src/google/protobuf/compiler/objectivec/objectivec_map_field.h
+++ b/src/google/protobuf/compiler/objectivec/map_field.h
@@ -34,7 +34,7 @@
#include <map>
#include <string>
-#include "google/protobuf/compiler/objectivec/objectivec_field.h"
+#include "google/protobuf/compiler/objectivec/field.h"
namespace google {
namespace protobuf {
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_message.cc b/src/google/protobuf/compiler/objectivec/message.cc
similarity index 98%
rename from src/google/protobuf/compiler/objectivec/objectivec_message.cc
rename to src/google/protobuf/compiler/objectivec/message.cc
index 9816149..530b7cd 100644
--- a/src/google/protobuf/compiler/objectivec/objectivec_message.cc
+++ b/src/google/protobuf/compiler/objectivec/message.cc
@@ -28,7 +28,7 @@
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#include "google/protobuf/compiler/objectivec/objectivec_message.h"
+#include "google/protobuf/compiler/objectivec/message.h"
#include <algorithm>
#include <iostream>
@@ -36,9 +36,9 @@
#include "absl/strings/escaping.h"
#include "absl/strings/str_cat.h"
-#include "google/protobuf/compiler/objectivec/objectivec_enum.h"
-#include "google/protobuf/compiler/objectivec/objectivec_extension.h"
-#include "google/protobuf/compiler/objectivec/objectivec_helpers.h"
+#include "google/protobuf/compiler/objectivec/enum.h"
+#include "google/protobuf/compiler/objectivec/extension.h"
+#include "google/protobuf/compiler/objectivec/helpers.h"
#include "google/protobuf/descriptor.pb.h"
#include "google/protobuf/io/printer.h"
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_message.h b/src/google/protobuf/compiler/objectivec/message.h
similarity index 96%
rename from src/google/protobuf/compiler/objectivec/objectivec_message.h
rename to src/google/protobuf/compiler/objectivec/message.h
index 641a518..7eb8c2d 100644
--- a/src/google/protobuf/compiler/objectivec/objectivec_message.h
+++ b/src/google/protobuf/compiler/objectivec/message.h
@@ -34,8 +34,8 @@
#include <string>
#include <set>
#include <vector>
-#include "google/protobuf/compiler/objectivec/objectivec_field.h"
-#include "google/protobuf/compiler/objectivec/objectivec_oneof.h"
+#include "google/protobuf/compiler/objectivec/field.h"
+#include "google/protobuf/compiler/objectivec/oneof.h"
#include "google/protobuf/descriptor.h"
#include "google/protobuf/io/printer.h"
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_message_field.cc b/src/google/protobuf/compiler/objectivec/message_field.cc
similarity index 97%
rename from src/google/protobuf/compiler/objectivec/objectivec_message_field.cc
rename to src/google/protobuf/compiler/objectivec/message_field.cc
index e889c6e..675b479 100644
--- a/src/google/protobuf/compiler/objectivec/objectivec_message_field.cc
+++ b/src/google/protobuf/compiler/objectivec/message_field.cc
@@ -31,8 +31,8 @@
#include <map>
#include <string>
-#include "google/protobuf/compiler/objectivec/objectivec_message_field.h"
-#include "google/protobuf/compiler/objectivec/objectivec_helpers.h"
+#include "google/protobuf/compiler/objectivec/message_field.h"
+#include "google/protobuf/compiler/objectivec/helpers.h"
#include "google/protobuf/io/printer.h"
namespace google {
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_message_field.h b/src/google/protobuf/compiler/objectivec/message_field.h
similarity index 97%
rename from src/google/protobuf/compiler/objectivec/objectivec_message_field.h
rename to src/google/protobuf/compiler/objectivec/message_field.h
index 19f23a2..7ed1cf2 100644
--- a/src/google/protobuf/compiler/objectivec/objectivec_message_field.h
+++ b/src/google/protobuf/compiler/objectivec/message_field.h
@@ -34,7 +34,7 @@
#include <map>
#include <string>
-#include "google/protobuf/compiler/objectivec/objectivec_field.h"
+#include "google/protobuf/compiler/objectivec/field.h"
namespace google {
namespace protobuf {
diff --git a/src/google/protobuf/compiler/objectivec/names.cc b/src/google/protobuf/compiler/objectivec/names.cc
index 5ae447f..a72da60 100644
--- a/src/google/protobuf/compiler/objectivec/names.cc
+++ b/src/google/protobuf/compiler/objectivec/names.cc
@@ -50,7 +50,7 @@
#include "absl/strings/str_split.h"
#include "absl/strings/strip.h"
#include "google/protobuf/compiler/objectivec/names.h"
-#include "google/protobuf/compiler/objectivec/objectivec_nsobject_methods.h"
+#include "google/protobuf/compiler/objectivec/nsobject_methods.h"
#include "google/protobuf/descriptor.pb.h"
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/io/io_win32.h"
@@ -377,7 +377,7 @@
const char* const kReservedWordList[] = {
// Note NSObject Methods:
- // These are brought in from objectivec_nsobject_methods.h that is generated
+ // These are brought in from nsobject_methods.h that is generated
// using method_dump.sh. See kNSObjectMethods below.
// Objective C "keywords" that aren't in C
diff --git a/src/google/protobuf/compiler/objectivec/names.h b/src/google/protobuf/compiler/objectivec/names.h
index e75738f..83fb24c 100644
--- a/src/google/protobuf/compiler/objectivec/names.h
+++ b/src/google/protobuf/compiler/objectivec/names.h
@@ -70,7 +70,7 @@
std::string PROTOC_EXPORT GetForcedPackagePrefix();
void PROTOC_EXPORT SetForcedPackagePrefix(const std::string& prefix);
-// Generator Prefix Validation Options (see objectivec_generator.cc for a
+// Generator Prefix Validation Options (see generator.cc for a
// description of each):
struct Options {
Options();
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_nsobject_methods.h b/src/google/protobuf/compiler/objectivec/nsobject_methods.h
similarity index 100%
rename from src/google/protobuf/compiler/objectivec/objectivec_nsobject_methods.h
rename to src/google/protobuf/compiler/objectivec/nsobject_methods.h
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_oneof.cc b/src/google/protobuf/compiler/objectivec/oneof.cc
similarity index 97%
rename from src/google/protobuf/compiler/objectivec/objectivec_oneof.cc
rename to src/google/protobuf/compiler/objectivec/oneof.cc
index 279928b..2202498 100644
--- a/src/google/protobuf/compiler/objectivec/objectivec_oneof.cc
+++ b/src/google/protobuf/compiler/objectivec/oneof.cc
@@ -28,13 +28,13 @@
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#include "google/protobuf/compiler/objectivec/objectivec_oneof.h"
+#include "google/protobuf/compiler/objectivec/oneof.h"
#include <map>
#include <string>
#include "absl/strings/str_cat.h"
-#include "google/protobuf/compiler/objectivec/objectivec_helpers.h"
+#include "google/protobuf/compiler/objectivec/helpers.h"
#include "google/protobuf/io/printer.h"
namespace google {
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_oneof.h b/src/google/protobuf/compiler/objectivec/oneof.h
similarity index 100%
rename from src/google/protobuf/compiler/objectivec/objectivec_oneof.h
rename to src/google/protobuf/compiler/objectivec/oneof.h
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_options.h b/src/google/protobuf/compiler/objectivec/options.h
similarity index 97%
rename from src/google/protobuf/compiler/objectivec/objectivec_options.h
rename to src/google/protobuf/compiler/objectivec/options.h
index 07b90b3..388d1ca 100644
--- a/src/google/protobuf/compiler/objectivec/objectivec_options.h
+++ b/src/google/protobuf/compiler/objectivec/options.h
@@ -38,7 +38,7 @@
namespace compiler {
namespace objectivec {
-// Generation options, documented within objectivec_generator.cc.
+// Generation options, documented within generator.cc.
struct GenerationOptions {
std::string generate_for_named_framework;
std::string named_framework_to_proto_path_mappings_path;
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_primitive_field.cc b/src/google/protobuf/compiler/objectivec/primitive_field.cc
similarity index 95%
rename from src/google/protobuf/compiler/objectivec/objectivec_primitive_field.cc
rename to src/google/protobuf/compiler/objectivec/primitive_field.cc
index c9339a5..b64dd42 100644
--- a/src/google/protobuf/compiler/objectivec/objectivec_primitive_field.cc
+++ b/src/google/protobuf/compiler/objectivec/primitive_field.cc
@@ -28,13 +28,13 @@
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#include "google/protobuf/compiler/objectivec/objectivec_primitive_field.h"
+#include "google/protobuf/compiler/objectivec/primitive_field.h"
#include <map>
#include <string>
#include "absl/strings/str_cat.h"
-#include "google/protobuf/compiler/objectivec/objectivec_helpers.h"
+#include "google/protobuf/compiler/objectivec/helpers.h"
#include "google/protobuf/io/printer.h"
namespace google {
@@ -71,7 +71,7 @@
case OBJECTIVECTYPE_ENUM:
return "int32_t";
case OBJECTIVECTYPE_MESSAGE:
- return NULL; // Messages go through objectivec_message_field.cc|h.
+ return NULL; // Messages go through message_field.cc|h.
}
// Some compilers report reaching end of function even though all cases of
@@ -104,7 +104,7 @@
case OBJECTIVECTYPE_ENUM:
return "Enum";
case OBJECTIVECTYPE_MESSAGE:
- // Want NSArray (but goes through objectivec_message_field.cc|h).
+ // Want NSArray (but goes through message_field.cc|h).
return "";
}
diff --git a/src/google/protobuf/compiler/objectivec/objectivec_primitive_field.h b/src/google/protobuf/compiler/objectivec/primitive_field.h
similarity index 98%
rename from src/google/protobuf/compiler/objectivec/objectivec_primitive_field.h
rename to src/google/protobuf/compiler/objectivec/primitive_field.h
index 8948b48..904cd65 100644
--- a/src/google/protobuf/compiler/objectivec/objectivec_primitive_field.h
+++ b/src/google/protobuf/compiler/objectivec/primitive_field.h
@@ -31,7 +31,7 @@
#ifndef GOOGLE_PROTOBUF_COMPILER_OBJECTIVEC_PRIMITIVE_FIELD_H__
#define GOOGLE_PROTOBUF_COMPILER_OBJECTIVEC_PRIMITIVE_FIELD_H__
-#include "google/protobuf/compiler/objectivec/objectivec_field.h"
+#include "google/protobuf/compiler/objectivec/field.h"
namespace google {
namespace protobuf {
diff --git a/src/google/protobuf/compiler/objectivec/method_dump.sh b/src/google/protobuf/compiler/objectivec/method_dump.sh
index 193825d..6592212 100755
--- a/src/google/protobuf/compiler/objectivec/method_dump.sh
+++ b/src/google/protobuf/compiler/objectivec/method_dump.sh
@@ -1,7 +1,7 @@
#!/bin/bash
# Updates objectivec_nsobject_methods.h by generating a list of all of the properties
# and methods on NSObject that Protobufs should not overload from iOS and macOS combined.
#
# The rules:
# - No property should ever be overloaded.
@@ -110,7 +110,7 @@
)
# Check to make sure we are updating the correct file.
-if [[ ! -e "objectivec_nsobject_methods.h" ]]; then
+if [[ ! -e "nsobject_methods.h" ]]; then
echo "error: Must be run in the src/google/protobuf/compiler/objectivec directory"
exit 1
fi
@@ -154,7 +154,7 @@
# Check for differences. Turn off error checking because we expect diff to fail when
# there are no differences.
set +e
-diff_out=$(diff -I "^//.*$" "$temp_dir"/methods_sorted.txt objectivec_nsobject_methods.h)
+diff_out=$(diff -I "^//.*$" "$temp_dir"/methods_sorted.txt nsobject_methods.h)
removed_methods=$(echo "$diff_out" | grep '^>.*$')
set -e
if [[ -n "$removed_methods" ]]; then
@@ -168,12 +168,12 @@
echo "$removed_methods"
echo ""
echo "New Version: $temp_dir/methods_sorted.txt"
- echo "Old Version: objectivec_nsobject_methods.h"
+ echo "Old Version: nsobject_methods.h"
exit 1
fi
if [[ -n "$diff_out" ]]; then
echo "Added Methods:"
echo "$(echo "$diff_out" | grep '^<.*$' | sed -e 's/^< "\(.*\)",$/ \1/')"
fi;
-cp "$temp_dir"/methods_sorted.txt objectivec_nsobject_methods.h
+cp "$temp_dir"/methods_sorted.txt nsobject_methods.h
rm -rf "$temp_dir"
@@ -1,7 +1,7 @@
#!/bin/bash
-# Updates objectivec_nsobject_methods.h by generating a list of all of the properties
-# and methods on NSObject that Protobufs should not overload from iOS and macOS combined.
+# Updates nsobject_methods.h by generating a list of all of the properties and
+# methods on NSObject that Protobufs should not overload from iOS and macOS combined.
#
# The rules: